@@ -36,6 +36,7 @@ from typing import (
     Union,
     Optional,
     Awaitable,
+    Callable,
     NewType,
     ClassVar,
     Dict,
@@ -505,6 +506,12 @@ class Flow:
     async def on_interaction(self, token, id, command_name: Text, bot_token: Showflake[str], type: int, data: JsonOutput, type_of_command: Optional[int] = None):
         pass
 
+    async def on_components(self, d):
+        pass
+
+    async def on_modal_sumbit(self, d):
+        pass
+
     async def on_register(self):
         pass
 
@@ -583,6 +590,8 @@ class Flow:
             self.on_channel__id = ons["channel"][1]
 
         self.on_interaction = ons["interaction"]
+        self.on_components = ons["components"]
+        self.on_modal_sumbit = ons["modalsumbit"]
         self.on_register = ons["register"]
         self.register2 = ons["register2"]
 
@@ -667,12 +676,14 @@ class Flow:
                 await self.on_messaged(_e)
 
             elif event.type == "INTERACTION_CREATE":
-                if event.data["type"] == 2:
+                if event.data["type"] == 2:  # Application Commands
                     await self.on_interaction(event.data["token"], event.data["id"], event.data["data"]["name"],
                                               self.token, event.data["type"], event.data, event.data["data"]["type"])
-                else:
-                    await self.on_interaction(event.data["token"], event.data["id"], event.data["data"]["name"],
-                                              self.token, event.data["type"], event.data, None)
+                if event.data["type"] == 3 or event.data["type"] == 4:  # Components
+                    await self.on_components(event.data)
+
+                if event.data["type"] == 5:  # Modal Sumbit
+                    await self.on_modal_sumbit(event.data)
 
             elif event.type == "MESSAGE_REACTION_ADD":
                 from disspy.reaction import DisEmoji, DisReaction
@@ -751,6 +762,7 @@ class DisApi(_RequestsUserClass):
         """
         super().__init__()
 
+        self.comsevs = {}
         self._headers = {'Authorization': f'Bot {token}', "content-type": "application/json"}
         self.app_commands_jsons = []
 
@@ -776,7 +788,7 @@ class DisApi(_RequestsUserClass):
 
         return DisMessage(_d, self.token)
 
-    async def run(self, status, ons: Dict[Text, Awaitable], debug: bool, act: Dict[str, Any]) -> NoReturn:
+    async def run(self, status, ons: Dict[Text, Callable], debug: bool, act: Dict[str, Any]) -> NoReturn:
         """
         Run the flow of DisApi or run the bot.
         Running bot in Discord, changing status and registering
@@ -790,6 +802,8 @@ class DisApi(_RequestsUserClass):
         """
         ons["register2"] = self._register2
         ons["interaction"] = self._on_interaction
+        ons["components"] = self._on_components
+        ons["modalsumbit"] = self._on_modal_sumbit
 
         _url = f"{_mainurl()}applications/{self.application_id}/commands"
 
@@ -892,6 +906,29 @@ class DisApi(_RequestsUserClass):
                 except KeyError:
                     print("What! Application command is invalid")
 
+    async def _on_components(self, d):
+        if d["data"]["component_type"] == 2:
+            from disspy.application_commands import Context
+            _ctx = Context(d["token"], d["id"], self.token)
+            await self.comsevs[d["data"]["custom_id"]](_ctx)
+        if d["data"]["component_type"] == 3:
+            from disspy.application_commands import Context
+            _ctx = Context(d["token"], d["id"], self.token)
+            _vs = d["data"]["values"]
+            await self.comsevs[d["data"]["custom_id"]](_ctx, _vs)
+
+    async def _on_modal_sumbit(self, d):
+        from disspy.application_commands import Context
+        _ctx = Context(d["token"], d["id"], self.token)
+        coms = d["data"]["components"][0]["components"]
+        _v = ""
+
+        for i in coms:
+            if i["custom_id"] == d["data"]["custom_id"]:
+                _v = i["value"]
+
+        await self.comsevs[d["data"]["custom_id"]](_ctx, _v)
+
     def get_user(self, user_id: UserId) -> DisUser:
         """
         Get user by id
@@ -973,7 +1010,7 @@ class DisApi(_RequestsUserClass):
         elif payload["type"] == 2:
             # Register interaction func to User Commands
             try:
-                if payload["description"]:
+                if not payload["description"]:
                     self.app_commands_jsons.append(payload)
 
                     app_func_register(1)
@@ -985,7 +1022,7 @@ class DisApi(_RequestsUserClass):
         elif payload["type"] == 3:
             # Register interaction func to Message Commands
             try:
-                if payload["description"]:
+                if not payload["description"]:
                     self.app_commands_jsons.append(payload)
 
                     app_func_register(2)
